# Basin Entropy

This algorithm was proposed by Daza et al., it computes the basin entropy of a computed basin of attraction on a regular grid.The function return the basin entropy and the boundary basin entropy.


* A. Daza, A. Wagemakers, B. Georgeot, D. Guéry-Odelin and M. A. F. Sanjuán, Basin entropy: a new tool to analyze uncertainty in dynamical systems, Sci. Rep., 6, 31416, (2016).
